@@ -64,6 +64,9 @@ my_shutdown(int s, int how)
 	rv = shutdown(s, how);
 
 	if (rv == -1) {
+#ifdef	ENOTCONN
+	    if (errno != ENOTCONN)
+#endif
 		error_error("shutdown() failed", errno);
 	}
 }
