@@ -1,3 +1,4 @@
+#include <errno.h>
 #include <stdlib.h>
 #include <fcntl.h>
 #include "prngd.h"
@@ -17,8 +18,12 @@ void non_blocking(int fd, int on)
 {
   int flags;
 
-  if ((flags = fcntl(fd, F_GETFL, 0)) == -1)
-    abort();
-  if (fcntl(fd, F_SETFL, on ? flags | PATTERN : flags & ~PATTERN) == -1)
-    abort();
+  if ((flags = fcntl(fd, F_GETFL, 0)) == -1) {
+    error_fatal("fcntl() failed to get file descriptor flags", errno);
+    exit(EXIT_FAILURE);
+  }
+  if (fcntl(fd, F_SETFL, on ? flags | PATTERN : flags & ~PATTERN) == -1) {
+    error_fatal("fnctl() failed to set file descriptor flags", errno);
+    exit(EXIT_FAILURE);
+  }
 }
