@@ -6,6 +6,7 @@
 #include <unistd.h>
 #include <fcntl.h>
 #include <syslog.h>
+#include <stdarg.h>
 
 #include "config.h"
 #include "prngd_version.h"
@@ -16,6 +17,12 @@
 #ifndef HAVE_DAEMON
 int daemon(int nochdir, int noclose);
 #endif
+#ifndef HAVE_SNPRINTF
+int snprintf(char *str, size_t count, const char *fmt, ...);
+#endif /* !HAVE_SNPRINTF */
+#ifndef HAVE_VSNPRINTF
+int vsnprintf(char *str, size_t count, const char *fmt, va_list args);
+#endif /* !HAVE_SNPRINTF */
 
 typedef struct {
   double rate;
@@ -35,7 +42,6 @@ typedef struct {
 #endif
 } seed_t;
 
-extern int randsavefd;
 extern int debug;
 extern int devnull;
 extern int limit_openfd;
@@ -55,7 +61,10 @@ void seed_stat(void);
 void rand_add(const void *buf, int num, double entropy);
 int rand_bytes(unsigned char *buf, int num);
 int rand_pool(void);
-int rand_init(int set_state_size, int set_entropy_needed);
+void rand_init(int set_state_size, int set_entropy_needed);
+
+/* What do we exit with when there is an error? */
+#define EXIT_FAILURE 1
 
 #define SHA_DIGEST_LENGTH 20
 /* The SHA block size and message digest sizes, in bytes */
@@ -87,3 +96,23 @@ ssize_t socket_read(int fd, void *buf, size_t num);
 ssize_t socket_write(int fd, void *buf, size_t num);
 
 int obtain_limit(void);
+
+/*
+ * error_handlers.c
+ */
+void* my_malloc(size_t);
+int my_pipe(int[2]);
+void my_dup2(int, int);
+void my_gettimeofday(struct timeval*, void*);
+void my_shutdown(int, int);
+
+/*
+ * error_log.c
+ */
+#ifndef SYSLOG_FACILITY
+#define SYSLOG_FACILITY LOG_DAEMON
+#endif
+void intitialise_syslog(void);
+void error_fatal(const char*, int);
+void error_error(const char*, int);
+void error_notice(const char*, int);
